EasyExtend.langlets.p4d.p4dbase.P4DList

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dbase :: Class P4DList |
[hide private]
[frames] | no frames]

# Class P4DList

    object --+
             |
          list --+
                 |
                P4DList

Known Subclasses:
  - bytelet.ByteletList

Class used to represent lists of P4D objects. A special property of P4DList objects is the provisioning of P4D object methods for P4DLists containing a single P4D element.

So P4DList([a]).m() == a.m() for P4D methods like child(), comment(), text() etc.

Instance Methods | [hide private]
search(self, filter_function) Uses a filter_function to search elements in this list. |
_get_tag(self) |
xmlstr(self, **kwd) |
p4dstr(self, **kwd) |
comment(self) |
CDATA(self) |
text(self) |
content(self) |
get(self, tag) |
attribute(self, name) |
attributes(self) |
child(self, tag) |
children(self, tag=None) |
first_child(self) |
update(self) |
__delitem__(self, key) del x[y] |
__getattr__(self, name) |
__setattr__(self, name, value) x.__setattr__('name', value) <==> x.name = value |
Inherited from `list`: `__add__`, `__contains__`, `__delslice__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__gt__`, `__hash__`, `__iadd__`, `__imul__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__new__`, `__repr__`, `__reversed__`, `__rmul__`, `__setitem__`, `__setslice__`, `append`, `count`, `extend`, `index`, `insert`, `pop`, `remove`, `reverse`, `sort` Inherited from `object`: `__delattr__`, `__reduce__`, `__reduce_ex__`, `__str__`

Properties | [hide private]
| tag
Inherited from `object`: `__class__`

Method Details | [hide private]

### search(self, filter_function) |
Uses a filter_function to search elements in this list. The search function is applied when

### __delitem__(self, key) (Index deletion operator) |
del x[y] Overrides: list.__delitem__ (inherited documentation)

### __setattr__(self, name, value) |
x.__setattr__('name', value) <==> x.name = value Overrides: object.__setattr__ (inherited documentation)

Property Details | [hide private]

### tag Get Method: _get_tag(self)